==> libsejda-java_3.2.84.orig.tar.gz: sejda-3.2.84/README.md <==
Sejda SDK (http://www.sejda.org)
=====
[![Build Status](https://travis-ci.org/torakiki/sejda.png)](https://travis-ci.org/torakiki/sejda)
[![License](http://img.shields.io/badge/license-AGPLv3-blue.svg)](http://www.gnu.org/licenses/agpl-3.0.html)

Sejda SDK is an open source, task oriented PDF editor SDK library written in Java.

Sejda SDK offers a set of "ready to go" manipulations implemented using [SAMBox](https://github.com/torakiki/sambox), a PDFBox fork that we maintain, but you can also provide your implementation using iText, iText 5.x, PDFBox or any other PDF engine and configure Sejda to use it.

Quick start: https://github.com/torakiki/sejda/wiki/Getting-Started

A full list of the available tasks: https://github.com/torakiki/sejda/wiki/Tasks

Sejda console
----
`sejda-console` is a command line tool that can be used directly from the terminal or from your own code.

Download latest from https://github.com/torakiki/sejda/releases

Get started: https://github.com/torakiki/sejda/wiki/Getting-Started

Web Interface
----
A web interface is available at http://sejda.com where the most commonly used tasks are available as online services:

[Split PDF by pages](http://sejda.com/split-pdf)

[Merge PDF](http://sejda.com/merge-pdf)

[Split PDF by chapters](http://sejda.com/split-pdf-by-bookmarks)

[Split PDF by size](http://sejda.com/split-pdf-by-size)

[Split PDF by size](http://sejda.com/split-pdf-by-size)

[Alternate/Mix PDF](http://sejda.com/merge-pdf)

[Extract Pages from PDF](http://sejda.com/extract-pdf-pages)

[Apply header/footer or page numbers to PDF pages](http://sejda.com/header-footer-pdf)

[Rotate PDF pages](http://sejda.com/rotate-pdf-pages)

[PDF to JPG Images](http://sejda.com/pdf-to-jpg)


License
----

Sejda 1.x is licensed under Apache License, Version 2.0

Sejda 2.x and 3.x are licensed under GNU Affero Public License 3.0

==> libsejda-java_4.1.7.orig.tar.gz: sejda-4.1.7/README.md <==
Sejda SDK (http://www.sejda.org)
=====
[![Build Status](https://travis-ci.org/torakiki/sejda.png)](https://travis-ci.org/torakiki/sejda)
[![License](http://img.shields.io/badge/license-AGPLv3-blue.svg)](http://www.gnu.org/licenses/agpl-3.0.html)

Sejda SDK is a task oriented PDF editor SDK library written in Java.

Sejda SDK offers a set of "ready to go" manipulations implemented using [SAMBox](https://github.com/torakiki/sambox), a PDFBox fork that we maintain, but you can also provide your implementation using iText, iText 5.x, PDFBox or any other PDF engine and configure Sejda to use it.

Quick start: https://github.com/torakiki/sejda/wiki/Getting-Started

A full list of the available tasks: https://github.com/torakiki/sejda/wiki/Tasks

Sejda SDK open source
----
Is a open source Java library providing a set of PDF manipulation tasks

Sejda SDK PRO
----
Is a commercial Java library built on top of the open source library and providing additional PDF manipulation tasks

Sejda console PRO
----
`sejda-console-pro` is a commercial command line tool that can be used directly from the terminal or from your own code.

Get started: https://github.com/torakiki/sejda/wiki/Getting-Started

Web Interface
----
A web interface is available at http://sejda.com where the most commonly used tasks are available as online services:

[Split PDF by pages](http://sejda.com/split-pdf)

[Merge PDF](http://sejda.com/merge-pdf)

[Split PDF by chapters](http://sejda.com/split-pdf-by-bookmarks)

[Split PDF by size](http://sejda.com/split-pdf-by-size)

[Split PDF by size](http://sejda.com/split-pdf-by-size)

[Alternate/Mix PDF](http://sejda.com/merge-pdf)

[Extract Pages from PDF](http://sejda.com/extract-pdf-pages)

[Apply header/footer or page numbers to PDF pages](http://sejda.com/header-footer-pdf)

[Rotate PDF pages](http://sejda.com/rotate-pdf-pages)

[PDF to JPG Images](http://sejda.com/pdf-to-jpg)


License
----

Sejda 1.x is licensed under Apache License, Version 2.0

Sejda 2.x and higher are licensed under GNU Affero Public License 3.0
